export declare const base: {
    "inherit": "inherit",
    "current": "currentColor",
    "transparent": "transparent"
};

export declare type BaseColor = keyof typeof base;

export declare type Color = BaseColor | RGBColor | ShadyColor;

export declare const color: (color: string) => string;

export declare const colorRGB: (color: RGBColor) => string;

export declare interface CSSBreakpointOptions extends KnownBreakpointOptions<CSSResultGroup> {
    screens: Screens;
    stylesheet?: CSSResultGroup;
    macros?: CSSMacros;
    screenSizeAt(knownBreakpoint: KnownBreakpoint): string;
    screenSizeAt(knownBreakpoint: KnownBreakpoint, alias: MediaQueryAlias): string;
    screenSizeAt(knownBreakpoint: KnownBreakpoint, alias?: MediaQueryAlias): string;
    resolveMacros(): string;
}

export declare class CSSBreakpointOptionsImplementer implements CSSBreakpointOptions {
    stylesheet?: CSSResultGroup;
    sm?: CSSResultGroup;
    md?: CSSResultGroup;
    lg?: CSSResultGroup;
    xl?: CSSResultGroup;
    dark?: CSSResultGroup;
    light?: CSSResultGroup;
    "2xl"?: CSSResultGroup;
    screens: Screens;
    macros?: CSSMacros;
    constructor(options?: Partial<CSSBreakpointOptions>);
    screenSizeAt: (knownBreakpoint: KnownBreakpoint, alias?: MediaQueryAlias) => string;
    resolveMacros: () => string;
    walkScreens(callback: (breakpoint: KnownBreakpoint, options: ScreenBreakpoints) => void): void;
}

export declare type CSSMacros = string;

export declare type CSSPart = string;

export declare type CSSResultGroup = any;

export declare const defaultBreakpointOptions: CSSBreakpointOptions;

export declare const defaultScreenOptions: Screens;

export declare const generateCSS: (options: CSSBreakpointOptions) => string;

export declare const generateMediaQuery: (option: MediaQueryAlias, value: string) => string;

export declare const isKnownBreakpoint: (value: string) => value is KnownBreakpoint;

export declare const isMediaQueryAlias: (value: string) => value is MediaQueryAlias;

export declare type KnownBreakpoint = 'sm' | 'md' | 'lg' | 'xl' | '2xl' | 'dark' | 'light';

export declare type KnownBreakpointOptions<T> = {
    [key in KnownBreakpoint]?: T;
};

export declare type KnownMediaQuery = 'aspect-ratio' | 'device-height' | 'device-width' | 'min-resolution' | 'max-resolution' | 'device-aspect-ratio' | 'min-device-height' | 'max-device-height' | 'min-device-width' | 'max-device-width' | 'min-device-aspect-ratio' | 'max-device-aspect-ratio' | 'orientation' | 'min-width' | 'max-width' | 'prefers-color-scheme';

export declare type KnownShadeKeys = keyof typeof shades;

export declare type KnownShades = 50 | 100 | 200 | 300 | 400 | 500 | 600 | 700 | 800 | 900 | 950;

export declare const kPatterns: Patterns;

export declare type MediaQueryAlias = 'min' | 'max' | 'minWidth' | 'maxWidth' | 'minimumWidth' | 'maximumWidth' | 'aspectRatio' | 'deviceHeight' | 'deviceWidth' | 'minResolution' | 'maxResolution' | 'deviceAspectRatio' | 'minDeviceHeight' | 'maxDeviceHeight' | 'minDeviceWidth' | 'maxDeviceWidth' | 'minDeviceAspectRatio' | 'maxDeviceAspectRatio' | 'orientation' | 'prefersColorScheme';

export declare const mediaQueryMap: {
    [key in MediaQueryAlias | KnownMediaQuery]: KnownMediaQuery;
};

declare type Patterns = (readonly [RegExp, Replacer])[];

/**
 * Replaces CSS patterns in strings using regular expressions and predefined patterns.
 * @param {string[] | string} entry - The CSS string or an array of CSS strings to be processed.
 * @param {Patterns} patterns - Optional. Custom replacement patterns. Default is predefined patterns.
 * @returns {string} The processed CSS string.
 * @example
 *```typescript
 *console.log(
 *  `div { ${replace(
 *    'transition-colors',
 *    'transition-none',
 *    'blur-md',
 *    'drop-shadow-xl',
 *  )} }`
 *);
 *```
 *Will generate the following CSS string:
 *
 *```css
 *div {
 *  transition-property: color, background-color, border-color,
 *    text-decoration-color, fill, stroke;
 *  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
 *  transition-duration: 150ms;
 *  transition-property: none;
 *  filter: blur(12px);
 *  filter: drop-shadow(0 20px 13px rgb(0 0 0 / 0.03)) drop-shadow(
 *      0 8px 5px rgb(0 0 0 / 0.08)
 *    );
 *}
 *```
 */
export declare function replace(...entries: string[]): string;

declare type Replacer = string | ReplacerFn;

declare type ReplacerFn = (match: string, ...args: string[]) => string;

export declare function resolveMacros(this: CSSBreakpointOptions): string;

export declare const rgb: {
    "aliceblue": [240, 248, 255],
    "antiquewhite": [250, 235, 215],
    "aqua": [0, 255, 255],
    "aquamarine": [127, 255, 212],
    "azure": [240, 255, 255],
    "beige": [245, 245, 220],
    "bisque": [255, 228, 196],
    "black": [0, 0, 0],
    "blanchedalmond": [255, 235, 205],
    "blue": [0, 0, 255],
    "blueviolet": [138, 43, 226],
    "brown": [165, 42, 42],
    "burlywood": [222, 184, 135],
    "cadetblue": [95, 158, 160],
    "chartreuse": [127, 255, 0],
    "chocolate": [210, 105, 30],
    "coral": [255, 127, 80],
    "cornflowerblue": [100, 149, 237],
    "cornsilk": [255, 248, 220],
    "crimson": [220, 20, 60],
    "cyan": [0, 255, 255],
    "darkblue": [0, 0, 139],
    "darkcyan": [0, 139, 139],
    "darkgoldenrod": [184, 134, 11],
    "darkgray": [169, 169, 169],
    "darkgreen": [0, 100, 0],
    "darkgrey": [169, 169, 169],
    "darkkhaki": [189, 183, 107],
    "darkmagenta": [139, 0, 139],
    "darkolivegreen": [85, 107, 47],
    "darkorange": [255, 140, 0],
    "darkorchid": [153, 50, 204],
    "darkred": [139, 0, 0],
    "darksalmon": [233, 150, 122],
    "darkseagreen": [143, 188, 143],
    "darkslateblue": [72, 61, 139],
    "darkslategray": [47, 79, 79],
    "darkslategrey": [47, 79, 79],
    "darkturquoise": [0, 206, 209],
    "darkviolet": [148, 0, 211],
    "deeppink": [255, 20, 147],
    "deepskyblue": [0, 191, 255],
    "dimgray": [105, 105, 105],
    "dimgrey": [105, 105, 105],
    "dodgerblue": [30, 144, 255],
    "firebrick": [178, 34, 34],
    "floralwhite": [255, 250, 240],
    "forestgreen": [34, 139, 34],
    "fuchsia": [255, 0, 255],
    "gainsboro": [220, 220, 220],
    "ghostwhite": [248, 248, 255],
    "gold": [255, 215, 0],
    "goldenrod": [218, 165, 32],
    "gray": [128, 128, 128],
    "green": [0, 128, 0],
    "greenyellow": [173, 255, 47],
    "grey": [128, 128, 128],
    "honeydew": [240, 255, 240],
    "hotpink": [255, 105, 180],
    "indianred": [205, 92, 92],
    "indigo": [75, 0, 130],
    "ivory": [255, 255, 240],
    "khaki": [240, 230, 140],
    "lavender": [230, 230, 250],
    "lavenderblush": [255, 240, 245],
    "lawngreen": [124, 252, 0],
    "lemonchiffon": [255, 250, 205],
    "lightblue": [173, 216, 230],
    "lightcoral": [240, 128, 128],
    "lightcyan": [224, 255, 255],
    "lightgoldenrodyellow": [250, 250, 210],
    "lightgray": [211, 211, 211],
    "lightgreen": [144, 238, 144],
    "lightgrey": [211, 211, 211],
    "lightpink": [255, 182, 193],
    "lightsalmon": [255, 160, 122],
    "lightseagreen": [32, 178, 170],
    "lightskyblue": [135, 206, 250],
    "lightslategray": [119, 136, 153],
    "lightslategrey": [119, 136, 153],
    "lightsteelblue": [176, 196, 222],
    "lightyellow": [255, 255, 224],
    "lime": [0, 255, 0],
    "limegreen": [50, 205, 50],
    "linen": [250, 240, 230],
    "magenta": [255, 0, 255],
    "maroon": [128, 0, 0],
    "mediumaquamarine": [102, 205, 170],
    "mediumblue": [0, 0, 205],
    "mediumorchid": [186, 85, 211],
    "mediumpurple": [147, 112, 219],
    "mediumseagreen": [60, 179, 113],
    "mediumslateblue": [123, 104, 238],
    "mediumspringgreen": [0, 250, 154],
    "mediumturquoise": [72, 209, 204],
    "mediumvioletred": [199, 21, 133],
    "midnightblue": [25, 25, 112],
    "mintcream": [245, 255, 250],
    "mistyrose": [255, 228, 225],
    "moccasin": [255, 228, 181],
    "navajowhite": [255, 222, 173],
    "navy": [0, 0, 128],
    "oldlace": [253, 245, 230],
    "olive": [128, 128, 0],
    "olivedrab": [107, 142, 35],
    "orange": [255, 165, 0],
    "orangered": [255, 69, 0],
    "orchid": [218, 112, 214],
    "palegoldenrod": [238, 232, 170],
    "palegreen": [152, 251, 152],
    "paleturquoise": [175, 238, 238],
    "palevioletred": [219, 112, 147],
    "papayawhip": [255, 239, 213],
    "peachpuff": [255, 218, 185],
    "peru": [205, 133, 63],
    "pink": [255, 192, 203],
    "plum": [221, 160, 221],
    "powderblue": [176, 224, 230],
    "purple": [128, 0, 128],
    "rebeccapurple": [102, 51, 153],
    "red": [255, 0, 0],
    "rosybrown": [188, 143, 143],
    "royalblue": [65, 105, 225],
    "saddlebrown": [139, 69, 19],
    "salmon": [250, 128, 114],
    "sandybrown": [244, 164, 96],
    "seagreen": [46, 139, 87],
    "seashell": [255, 245, 238],
    "sienna": [160, 82, 45],
    "silver": [192, 192, 192],
    "skyblue": [135, 206, 235],
    "slateblue": [106, 90, 205],
    "slategray": [112, 128, 144],
    "slategrey": [112, 128, 144],
    "snow": [255, 250, 250],
    "springgreen": [0, 255, 127],
    "steelblue": [70, 130, 180],
    "tan": [210, 180, 140],
    "teal": [0, 128, 128],
    "thistle": [216, 191, 216],
    "tomato": [255, 99, 71],
    "turquoise": [64, 224, 208],
    "violet": [238, 130, 238],
    "wheat": [245, 222, 179],
    "white": [255, 255, 255],
    "whitesmoke": [245, 245, 245],
    "yellow": [255, 255, 0],
    "yellowgreen": [154, 205, 50]
};

export declare type RGBColor = keyof typeof rgb;

export declare type ScreenBreakpoints = {
    [key in MediaQueryAlias | KnownMediaQuery]?: string;
};

export declare type Screens = {
    [key in KnownBreakpoint]: ScreenBreakpoints;
};

export declare function screenSizeAt(this: CSSBreakpointOptions, knownBreakpoint: KnownBreakpoint, alias?: MediaQueryAlias): string;

export declare const shades: {
    "slate": [
    [248, 250, 252],
    [241, 245, 249],
    [226, 232, 240],
    [203, 213, 225],
    [148, 163, 184],
    [100, 116, 139],
    [71, 85, 105],
    [51, 65, 85],
    [30, 41, 59],
    [15, 23, 42],
    [2, 6, 23]
    ],
    "gray": [
    [249, 250, 251],
    [243, 244, 246],
    [229, 231, 235],
    [209, 213, 219],
    [156, 163, 175],
    [107, 114, 128],
    [75, 85, 99],
    [55, 65, 81],
    [31, 41, 55],
    [17, 24, 39],
    [3, 7, 18]
    ],
    "zinc": [
    [250, 250, 250],
    [244, 244, 245],
    [228, 228, 231],
    [212, 212, 216],
    [161, 161, 170],
    [113, 113, 122],
    [82, 82, 91],
    [63, 63, 70],
    [39, 39, 42],
    [24, 24, 27],
    [9, 9, 11]
    ],
    "neutral": [
    [250, 250, 250],
    [245, 245, 245],
    [229, 229, 229],
    [212, 212, 212],
    [163, 163, 163],
    [115, 115, 115],
    [82, 82, 82],
    [64, 64, 64],
    [38, 38, 38],
    [23, 23, 23],
    [10, 10, 10]
    ],
    "stone": [
    [250, 250, 249],
    [245, 245, 244],
    [231, 229, 228],
    [214, 211, 209],
    [168, 162, 158],
    [120, 113, 108],
    [87, 83, 78],
    [68, 64, 60],
    [41, 37, 36],
    [28, 25, 23],
    [12, 10, 9]
    ],
    "red": [
    [254, 242, 242],
    [254, 226, 226],
    [254, 202, 202],
    [252, 165, 165],
    [248, 113, 113],
    [239, 68, 68],
    [220, 38, 38],
    [185, 28, 28],
    [153, 27, 27],
    [127, 29, 29],
    [69, 10, 10]
    ],
    "orange": [
    [255, 247, 237],
    [255, 237, 213],
    [254, 215, 170],
    [253, 186, 116],
    [251, 146, 60],
    [249, 115, 22],
    [234, 88, 12],
    [194, 65, 12],
    [154, 52, 18],
    [124, 45, 18],
    [67, 20, 7]
    ],
    "amber": [
    [255, 251, 235],
    [254, 243, 199],
    [253, 230, 138],
    [252, 211, 77],
    [251, 191, 36],
    [245, 158, 11],
    [217, 119, 6],
    [180, 83, 9],
    [146, 64, 14],
    [120, 53, 15],
    [69, 26, 3]
    ],
    "yellow": [
    [254, 252, 232],
    [254, 249, 195],
    [254, 240, 138],
    [253, 224, 71],
    [250, 204, 21],
    [234, 179, 8],
    [202, 138, 4],
    [161, 98, 7],
    [133, 77, 14],
    [113, 63, 18],
    [66, 32, 6]
    ],
    "lime": [
    [247, 254, 231],
    [236, 252, 203],
    [217, 249, 157],
    [190, 242, 100],
    [163, 230, 53],
    [132, 204, 22],
    [101, 163, 13],
    [77, 124, 15],
    [63, 98, 18],
    [54, 83, 20],
    [26, 46, 5]
    ],
    "green": [
    [240, 253, 244],
    [220, 252, 231],
    [187, 247, 208],
    [134, 239, 172],
    [74, 222, 128],
    [34, 197, 94],
    [22, 163, 74],
    [21, 128, 61],
    [22, 101, 52],
    [20, 83, 45],
    [5, 46, 22]
    ],
    "emerald": [
    [236, 253, 245],
    [209, 250, 229],
    [167, 243, 208],
    [110, 231, 183],
    [52, 211, 153],
    [16, 185, 129],
    [5, 150, 105],
    [4, 120, 87],
    [6, 95, 70],
    [6, 78, 59],
    [2, 44, 34]
    ],
    "teal": [
    [240, 253, 250],
    [204, 251, 241],
    [153, 246, 228],
    [94, 234, 212],
    [45, 212, 191],
    [20, 184, 166],
    [13, 148, 136],
    [15, 118, 110],
    [17, 94, 89],
    [19, 78, 74],
    [4, 47, 46]
    ],
    "cyan": [
    [236, 254, 255],
    [207, 250, 254],
    [165, 243, 252],
    [103, 232, 249],
    [34, 211, 238],
    [6, 182, 212],
    [8, 145, 178],
    [14, 116, 144],
    [21, 94, 117],
    [22, 78, 99],
    [8, 51, 68]
    ],
    "sky": [
    [240, 249, 255],
    [224, 242, 254],
    [186, 230, 253],
    [125, 211, 252],
    [56, 189, 248],
    [14, 165, 233],
    [2, 132, 199],
    [3, 105, 161],
    [7, 89, 133],
    [12, 74, 110],
    [8, 47, 73]
    ],
    "blue": [
    [239, 246, 255],
    [219, 234, 254],
    [191, 219, 254],
    [147, 197, 253],
    [96, 165, 250],
    [59, 130, 246],
    [37, 99, 235],
    [29, 78, 216],
    [30, 64, 175],
    [30, 58, 138],
    [23, 37, 84]
    ],
    "indigo": [
    [238, 242, 255],
    [224, 231, 255],
    [199, 210, 254],
    [165, 180, 252],
    [129, 140, 248],
    [99, 102, 241],
    [79, 70, 229],
    [67, 56, 202],
    [55, 48, 163],
    [49, 46, 129],
    [30, 27, 75]
    ],
    "violet": [
    [245, 243, 255],
    [237, 233, 254],
    [221, 214, 254],
    [196, 181, 253],
    [167, 139, 250],
    [139, 92, 246],
    [124, 58, 237],
    [109, 40, 217],
    [91, 33, 182],
    [76, 29, 149],
    [46, 16, 101]
    ],
    "purple": [
    [250, 245, 255],
    [243, 232, 255],
    [233, 213, 255],
    [216, 180, 254],
    [192, 132, 252],
    [168, 85, 247],
    [147, 51, 234],
    [126, 34, 206],
    [107, 33, 168],
    [88, 28, 135],
    [59, 7, 100]
    ],
    "fuchsia": [
    [253, 244, 255],
    [250, 232, 255],
    [245, 208, 254],
    [240, 171, 252],
    [232, 121, 249],
    [217, 70, 239],
    [192, 38, 211],
    [162, 28, 175],
    [134, 25, 143],
    [112, 26, 117],
    [74, 4, 78]
    ],
    "pink": [
    [253, 242, 248],
    [252, 231, 243],
    [251, 207, 232],
    [249, 168, 212],
    [244, 114, 182],
    [236, 72, 153],
    [219, 39, 119],
    [190, 24, 93],
    [157, 23, 77],
    [131, 24, 67],
    [80, 7, 36]
    ],
    "rose": [
    [255, 241, 242],
    [255, 228, 230],
    [254, 205, 211],
    [253, 164, 175],
    [251, 113, 133],
    [244, 63, 94],
    [225, 29, 72],
    [190, 18, 60],
    [159, 18, 57],
    [136, 19, 55],
    [76, 5, 25]
    ]
};

export declare type ShadyColor = `${KnownShadeKeys}-${KnownShades}`;

export declare function walkScreens(screens: Screens, callback: (breakpoint: KnownBreakpoint, options: ScreenBreakpoints) => void): void;

export { }
